Installation instructions — CommonNN Clustering documentation

# Installation instructions

## Requirements

The `cnnclustering` package is developed and tested in Python >=3.6. At runtime the package has a few mandatory third party dependencies. We recommend to install the latest version of:

> - `numpy`

> - `PyYAML`

> - `tqdm`

Optionally, additional functionality is available when the following packages are installed as well:

> - `matplotlib`

> - `pandas`

> - `networkx`

> - `scipy`

> - `sklearn`

## PyPi

    pip install cnnclustering

## Developement installation

Clone the source repository https://github.com/janjoswig/CommonNNClustering and use the package `cnnclustering` as you prefer it, e.g. install it via pip in editable mode.

    $ git clone https://github.com/janjoswig/CommonNNClustering
    $ cd CommonNNClustering
    $ pip install -e .

To recompile the Cython-extensions (requires `cython` installed) use:

    $ python setup.py build_ext --inplace